Return the total number of acquired transients for an MRS dataset.
Source:R/mrs_data_proc.R
Ntrans.RdReturn the total number of acquired transients for an MRS dataset.

R/mrs_data_proc.R
Ntrans.RdReturn the total number of acquired transients for an MRS dataset.