abfit_opts_v1_9_0: Return a list of options for an ABfit analysis to maintain...

View source: R/abfit.R

abfit_opts_v1_9_0R Documentation

Return a list of options for an ABfit analysis to maintain comparability with analyses performed with version 1.9.0 (and earlier) of spant.

Description

Return a list of options for an ABfit analysis to maintain comparability with analyses performed with version 1.9.0 (and earlier) of spant.

Usage

abfit_opts_v1_9_0(...)

Arguments

...

arguments passed to abfit_opts.

Value

full list of options.


spant documentation built on May 21, 2026, 5:07 p.m.