append_regs: Append multiple regressor data frames into a single data...

View source: R/fmrs.R

append_regsR Documentation

Append multiple regressor data frames into a single data frame.

Description

Append multiple regressor data frames into a single data frame.

Usage

append_regs(...)

Arguments

...

input regressor data frames.

Value

output regressor data frame.


spant documentation built on May 21, 2026, 5:07 p.m.