Apply and subtract a Gaussian smoother in the spectral domain.
Source:R/mrs_data_proc.R
bc_gauss.RdApply and subtract a Gaussian smoother in the spectral domain.

R/mrs_data_proc.R
bc_gauss.RdApply and subtract a Gaussian smoother in the spectral domain.