Calculate the sum of squares differences between two mrs_data objects.
Source:R/mrs_data_proc.R
calc_spec_diff.RdCalculate the sum of squares differences between two mrs_data objects.
Usage
calc_spec_diff(mrs_data, ref = NULL, xlim = c(4, 0.5))