Create a logical circular mask spanning the full extent of an n x n matrix.
Source:R/utils.R
circ_mask.RdCreate a logical circular mask spanning the full extent of an n x n matrix.

R/utils.R
circ_mask.RdCreate a logical circular mask spanning the full extent of an n x n matrix.