powered by
Return a time scale vector of acquisition times for a dynamic MRS scan. The first temporal scan is assigned a value of 0.
dyn_acq_times(mrs_data)
time scale vector in units of seconds.
MRS data.