Perform a zeroth order phase correction based on the phase of the first data point in the time-domain.
Source:R/mrs_data_proc.R
fp_phase_correct.RdPerform a zeroth order phase correction based on the phase of the first data point in the time-domain.