Return a character vector of molecules included in the GE BRAINO phantom.
Source:R/qm_simulation.R
get_1h_braino_basis_names.RdReturn a character vector of molecules included in the GE BRAINO phantom.

R/qm_simulation.R
get_1h_braino_basis_names.RdReturn a character vector of molecules included in the GE BRAINO phantom.