get_ants_dir: Return the ANTs installation directory, or throw an error if...

View source: R/ants_utils.R

get_ants_dirR Documentation

Return the ANTs installation directory, or throw an error if not found.

Description

Will check and return the "spant.ants_dir" option set by set_ants_dir. If not set, will search the spant_resources directory for ANTs and return the most recent version if multiple are found.

Usage

get_ants_dir()

Value

ANTs installation directory.


spant documentation built on May 8, 2026, 5:08 p.m.