Return a character array of names that may be used with the get_mol_paras function.
Source: R/mol_parameters.R
get_mol_names.RdReturn a character array of names that may be used with the
get_mol_paras function.