Get the indices of data points lying between two values (end > x > start).
Source:R/mrs_data_proc.R
get_seg_ind.RdGet the indices of data points lying between two values (end > x > start).

R/mrs_data_proc.R
get_seg_ind.RdGet the indices of data points lying between two values (end > x > start).