Return an array of amplitudes derived from fitting the initial points in the time domain and extrapolating back to t=0.
Source:R/mrs_data_proc.R
get_td_amp.RdReturn an array of amplitudes derived from fitting the initial points in the time domain and extrapolating back to t=0.