get_voi_cog: Calculate the centre of gravity for an image containing 0 and...

View source: R/image_reg.R

get_voi_cogR Documentation

Calculate the centre of gravity for an image containing 0 and 1's.

Description

Calculate the centre of gravity for an image containing 0 and 1's.

Usage

get_voi_cog(voi)

Arguments

voi

nifti object.

Value

triplet of x,y,z coordinates.


spant documentation built on May 8, 2026, 5:08 p.m.