Perform first-level spectral GLM analysis of an fMRS dataset.
Arguments
- regressor_df
a data frame containing temporal regressors to be applied to each spectral datapoint.
- analysis_dir
directory containing preprocessed data generated by the preproc_svs_dataset function.
- output_dir
directory to save glm results.
- exclude_labels
vector of labels of scans to exclude, eg poor quality data.
- labels
labels to describe each data set.
- xlim
spectral range to include in the analysis.
- vline
vertical lines to add to the plot.
- lb
linebroading to add in Hz before GLM analysis.
- return_results
function will return key outputs, defaults to FALSE.