Perform group-level spectral GLM analysis of an fMRS dataset.
Source:R/fmrs.R
glm_spec_fmrs_group.RdPerform group-level spectral GLM analysis of an fMRS dataset.
Usage
glm_spec_fmrs_group(
regressor_df,
analysis_dir = "spant_analysis",
exclude_labels = NULL,
labels = NULL
)Arguments
- regressor_df
a data frame containing temporal regressors to be applied to each spectral datapoint.
- analysis_dir
directory containing preprocessed data generated by the preproc_svs_dataset function.
- exclude_labels
vector of labels of scans to exclude, eg poor quality data.
- labels
labels to describe each data set.