Interleave the first and second half of a dynamic series.
Source:R/mrs_data_proc.R
interleave_dyns.RdInterleave the first and second half of a dynamic series.

R/mrs_data_proc.R
interleave_dyns.RdInterleave the first and second half of a dynamic series.