Check if the chemical shift dimension of an MRS data object is in the frequency domain.
Source:R/mrs_data_proc.R
is_fd.RdCheck if the chemical shift dimension of an MRS data object is in the frequency domain.

R/mrs_data_proc.R
is_fd.RdCheck if the chemical shift dimension of an MRS data object is in the frequency domain.