Mask the voxels outside an elliptical region spanning the MRSI dataset in the x-y plane.
Source:R/mrs_data_proc.R
mask_xy_ellipse.RdMask the voxels outside an elliptical region spanning the MRSI dataset in the x-y plane.

R/mrs_data_proc.R
mask_xy_ellipse.RdMask the voxels outside an elliptical region spanning the MRSI dataset in the x-y plane.