Match files based on a vector of input paths and a glob pattern. The glob pattern is appended to each path and should match one file only.
Source:R/utils.R
match_files.RdMatch files based on a vector of input paths and a glob pattern. The glob pattern is appended to each path and should match one file only.