Convert mrs_data object to a matrix, with spectral points in the column dimension and dynamics in the row dimension.
Source:R/mrs_data_proc.R
mrs_data2spec_mat.RdConvert mrs_data object to a matrix, with spectral points in the column dimension and dynamics in the row dimension.