mvifftshift: Perform an ifftshift on a matrix, with each column replaced...

View source: R/utils.R

mvifftshiftR Documentation

Perform an ifftshift on a matrix, with each column replaced by its shifted result.

Description

Perform an ifftshift on a matrix, with each column replaced by its shifted result.

Usage

mvifftshift(x)

Arguments

x

matrix input.

Value

output matrix.


spant documentation built on May 8, 2026, 5:08 p.m.