Display an interactive orthographic projection plot of a nifti object.
Source:R/interactive_plotting.R
ortho3_inter.RdDisplay an interactive orthographic projection plot of a nifti object.

R/interactive_plotting.R
ortho3_inter.RdDisplay an interactive orthographic projection plot of a nifti object.