Search for the highest peak in a spectral region and return the frequency, height and FWHM.
Source:R/mrs_data_proc.R
peak_info.RdSearch for the highest peak in a spectral region and return the frequency, height and FWHM.
Usage
peak_info(
mrs_data,
xlim = c(4, 0.5),
interp_f = 4,
scale = "ppm",
mode = "real"
)Arguments
- mrs_data
an object of class
mrs_data.- xlim
frequency range (default units of PPM) to search for the highest peak.
- interp_f
interpolation factor, defaults to 4x.
- scale
the units to use for the frequency scale, can be one of: "ppm", "hz" or "points".
- mode
spectral mode, can be : "real", "imag" or "mod".