Plot a 2D slice from an MRSI fit result object.
Arguments
- fit_res
fit_resultobject.- map
fit result values to display as a colour map. Can be specified as a character string or array of numeric values. Defaults to "tNAA".
- map_denom
fit result values to divide the map argument by. Can be specified as a character string (eg "tCr") or array of numeric values.
- slice
slice to plot in the z direction.
- zlim
range of values to plot.
- interp
interpolation factor.