qn_states: Get the quantum coherence matrix for a spin system.

View source: R/qm_simulation.R

qn_statesR Documentation

Get the quantum coherence matrix for a spin system.

Description

Get the quantum coherence matrix for a spin system.

Usage

qn_states(sys)

Arguments

sys

spin system object.

Value

quantum coherence number matrix.


spant documentation built on May 8, 2026, 5:08 p.m.