Resample a VOI to match a target image space using nearest-neighbour interpolation.
Source:R/image_reg.R
resample_voi.RdResample a VOI to match a target image space using nearest-neighbour interpolation.

R/image_reg.R
resample_voi.RdResample a VOI to match a target image space using nearest-neighbour interpolation.