Reslice a nifti object to match the orientation of mrs data.
Source:R/image_reg.R
reslice_to_mrs.RdReslice a nifti object to match the orientation of mrs data.

R/image_reg.R
reslice_to_mrs.RdReslice a nifti object to match the orientation of mrs data.