Return a time scale vector to match the FID of an MRS data object.
Source:R/mrs_data_proc.R
seconds.RdReturn a time scale vector to match the FID of an MRS data object.

R/mrs_data_proc.R
seconds.RdReturn a time scale vector to match the FID of an MRS data object.