STEAM sequence with ideal pulses using the z-rotation gradient simulation method described by Young et al JMR 140, 146-152 (1999).
Source:R/pulse_sequences.R
seq_steam_ideal_young.RdSTEAM sequence with ideal pulses using the z-rotation gradient simulation method described by Young et al JMR 140, 146-152 (1999).
Arguments
- spin_params
spin system definition.
- ft
transmitter frequency in Hz.
- ref
reference value for ppm scale.
- TE
sequence parameter in seconds.
- TM
sequence parameter in seconds.
- amp_scale
amplitude scaling factor. Set to 2 (default) to ensure correct scaling for water reference scaling. Set to 1 to maintain the inherent loss of signal associated with STEAM.