Simulate an ideal pulse excitation profile by smoothing a top-hat function with a Gaussian.
Source:R/utils.R
sim_th_excit_profile.RdSimulate an ideal pulse excitation profile by smoothing a top-hat function with a Gaussian.

R/utils.R
sim_th_excit_profile.RdSimulate an ideal pulse excitation profile by smoothing a top-hat function with a Gaussian.