smooth_dyns: Smooth data across the dynamic dimension with a Gaussian...

View source: R/mrs_data_proc.R

smooth_dynsR Documentation

Smooth data across the dynamic dimension with a Gaussian kernel.

Description

Smooth data across the dynamic dimension with a Gaussian kernel.

Usage

smooth_dyns(mrs_data, sigma)

Arguments

mrs_data

data to be smoothed.

sigma

standard deviation of the underlying Gaussian kernel in seconds.

Value

smoothed mrs_data object.


spant documentation built on May 21, 2026, 5:07 p.m.