Subtract the even dynamic scans from the odd dynamic scans.
Source:R/mrs_data_proc.R
sub_even_from_odd_dyns.RdSubtract the even dynamic scans from the odd dynamic scans.

R/mrs_data_proc.R
sub_even_from_odd_dyns.RdSubtract the even dynamic scans from the odd dynamic scans.