Subtract the odd dynamic scans from the even dynamic scans.
Source:R/mrs_data_proc.R
sub_odd_from_even_dyns.RdSubtract the odd dynamic scans from the even dynamic scans.

R/mrs_data_proc.R
sub_odd_from_even_dyns.RdSubtract the odd dynamic scans from the even dynamic scans.