Subtract mean rest spectrum from mean task spectrum after applying optimal linebroadening to the mean task spectrum. Usually used to correct for the BOLD lineshape narrowing effect in 1H fMRS data.
Source:R/mrs_data_proc.R
subtract_rest_task.RdSubtract mean rest spectrum from mean task spectrum after applying optimal linebroadening to the mean task spectrum. Usually used to correct for the BOLD lineshape narrowing effect in 1H fMRS data.
Usage
subtract_rest_task(mrs_data, task_vec, xlim = c(2.11, 1.91))