SNR is defined as the maximum signal value divided by the standard deviation of the noise.
Arguments
- mrs_data
an object of class
mrs_data.- sig_region
a ppm region to define where the maximum signal value should be estimated.
- noise_region
a ppm region to defined where the noise level should be estimated.
- p_order
polynomial order to fit to the noise region before estimating the standard deviation.
- interp_f
interpolation factor to improve detection of the highest signal value.
- full_output
output signal, noise and SNR values separately.