Combine MRSI coil data using the GLS method presented by An et al JMRI 37:1445-1450 (2013).
comb_coils_mrsi_gls(
metab,
noise_pts = 256,
noise_mrs = NULL,
bc_poly_noise = 2
)coil combined MRSI data.
MRSI data containing metabolite data.
number of points from the end of the FIDs to use for noise covariance estimation.
MRS data containing noise information for each coil.
baseline correct the noise samples with a polynomial in the time-domain. Defaults to 2, which performs a second-order polynomial correction. Set to NULL to disable.