Combine SVS coil data using the GLS method presented by An et al JMRI 37:1445-1450 (2013).
comb_coils_svs_gls(
metab,
ref = NULL,
noise_pts = 256,
noise_mrs = NULL,
use_mean_sens = TRUE,
use_ref_sens = FALSE,
change_order = NULL,
no_noise_corr = FALSE,
bc_poly_noise = 2
)coil combined MRS data.
MRS data containing metabolite data.
MRS data containing reference data (optional).
number of points from the end of the FIDs to use for noise covariance estimation.
MRS data containing noise information for each coil.
use the dynamic mean to estimate coil sensitivities.
use the reference data to estimate coil sensitivities.
change the order of the noise matrix reshaping, for testing purposes only.
assume noise is uncorrelated between coils, for testing purposes only. Defaults to FALSE.
baseline correct the noise samples with a polynomial in the time-domain. Defaults to 2, which performs a second-order polynomial correction. Set to NULL to disable.