def_N: Return the default number of data points in the spectral...

View source: R/spant.R

def_NR Documentation

Return the default number of data points in the spectral dimension.

Description

Return the default number of data points in the spectral dimension.

Usage

def_N()

Value

number of data points in the spectral dimension.


spant documentation built on May 8, 2026, 5:08 p.m.