| get_spant_resources_dir | R Documentation |
Usually used to store additional software, datasets and templates. An attempt will be made to create the folder if not found. The default resources directory is "spant_resources" located in the users HOME directory.
get_spant_resources_dir()
full path to the spant resources directory.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.