Learn R Programming

spant (version 4.4.0)

get_spant_resources_dir: Return the spant resources directory.

Description

Usually used to store additional software, datasets and templates. An attempt will be made to create the folder if not found. The default resources directory is "spant_resources" located in the users HOME directory.

Usage

get_spant_resources_dir()

Arguments

Value

full path to the spant resources directory.