get_spant_resources_dir: Return the spant resources directory.
Description
Usually used to store additional software, datasets and templates. An attempt
will be made to create the folder if not found. The default resources
directory is "spant_resources" located in the users HOME directory.
Usage
get_spant_resources_dir()
Value
full path to the spant resources directory.