Calculate the centre of gravity for an image containing 0 and 1's.
Source:R/image_reg.R
get_voi_cog.RdCalculate the centre of gravity for an image containing 0 and 1's.

R/image_reg.R
get_voi_cog.RdCalculate the centre of gravity for an image containing 0 and 1's.