Apply water reference scaling to a fitting results object to yield metabolite quantities in units of "mmol per Kg wet weight".
Source:R/amp_scaling.R
scale_amp_legacy.RdSee the LCModel manual (section 10.2) on water-scaling for details on the assumptions and relevant references. Use this type of concentration scaling to compare fit results with LCModel and TARQUIN defaults. Otherwise scale_amp_molal_pvc is the preferred method. Note, the LCModel manual (section 1.3) states:
Arguments
- fit_result
a result object generated from fitting.
- ref_data
water reference MRS data object.
- w_att
water attenuation factor (default = 0.7). Assumes water T2 of 80ms and a TE = 30 ms. exp(-30ms / 80ms) ~ 0.7.
- w_conc
assumed water concentration (default = 35880). Default value corresponds to typical white matter. Set to 43300 for gray matter, and 55556 for phantom measurements.
- ...
additional arguments to get_td_amp function.