Smooth data across the dynamic dimension with a Gaussian kernel.
Source:R/mrs_data_proc.R
smooth_dyns.RdSmooth data across the dynamic dimension with a Gaussian kernel.

R/mrs_data_proc.R
smooth_dyns.RdSmooth data across the dynamic dimension with a Gaussian kernel.