Set all spectral data points below a given percentage of the maximum to zero.
Source:R/mrs_data_proc.R
zero_spec_threshold.RdSet all spectral data points below a given percentage of the maximum to zero.

R/mrs_data_proc.R
zero_spec_threshold.RdSet all spectral data points below a given percentage of the maximum to zero.