zero_spec_threshold: Set all spectral data points below a given percentage of the maximum to zero.
Description
Set all spectral data points below a given percentage of the maximum to zero.
Usage
zero_spec_threshold(mrs_data, percent_max)
Value
mrs_data object with zeroed spectral data points.
Arguments
- mrs_data
data to be processed.
- percent_max
spectral data points smaller than this percentage value
will be set to zero.